==> blesta-5.10.2.zip: blesta/language/cs_cz/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Přepínání navigace';
$lang['AppController.sreader.dropdown'] = 'Přepínání rozbalovacího seznamu';
$lang['AppController.graphs.label.total'] = 'Celkem';
$lang['AppController.graphs.control_label.grouped'] = 'Seskupení';
$lang['AppController.graphs.control_label.expanded'] = 'Rozšířená stránka';
$lang['AppController.graphs.control_label.stream'] = 'Stream';
$lang['AppController.graphs.control_label.stacked'] = 'Stacked';
$lang['AppController.dates.monthabbr_dec'] = 'Prosinec';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_oct'] = 'Říjen';
$lang['AppController.dates.monthabbr_sep'] = 'Září';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Květen';
$lang['AppController.dates.monthabbr_apr'] = 'Duben';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_feb'] = 'Únor';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Prosinec';
$lang['AppController.dates.month_nov'] = 'Listopad';
$lang['AppController.dates.month_oct'] = 'Říjen';
$lang['AppController.dates.month_sep'] = 'září';
$lang['AppController.dates.month_aug'] = 'Srpen';
$lang['AppController.dates.month_jul'] = 'Červenec';
$lang['AppController.dates.month_jun'] = 'červen';
$lang['AppController.dates.month_may'] = 'Květen';
$lang['AppController.dates.month_apr'] = 'duben';
$lang['AppController.dates.month_mar'] = 'Březen';
$lang['AppController.dates.month_feb'] = 'Únor';
$lang['AppController.dates.month_jan'] = 'Leden';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Pá';
$lang['AppController.dates.dayabbr_thur'] = 'Čt';
$lang['AppController.dates.dayabbr_wed'] = 'St';
$lang['AppController.dates.dayabbr_tue'] = 'Út';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_sun'] = 'Sun';
$lang['AppController.dates.day_sat'] = 'Sobota';
$lang['AppController.dates.day_fri'] = 'Pátek';
$lang['AppController.dates.day_thu'] = 'Čtvrtek';
$lang['AppController.dates.day_wed'] = 'Středa';
$lang['AppController.dates.day_tue'] = 'Úterý';
$lang['AppController.dates.day_mon'] = 'Pondělí';
$lang['AppController.dates.day_sun'] = 'Neděle';
$lang['AppController.client_structure.text_managers'] = 'Manažeři';
$lang['AppController.client_structure.text_contacts'] = 'Kontakty';
$lang['AppController.client_structure.text_accounts'] = 'Platební účty';
$lang['AppController.client_structure.text_emails'] = 'Historie e-mailů';
$lang['AppController.client_structure.text_update_account'] = 'Správa účtu';
$lang['AppController.client_structure.text_login'] = 'Přihlášení';
$lang['AppController.client_structure.text_logout'] = 'Odhlášení';
$lang['AppController.client_structure.text_return_to_portal'] = 'Návrat na portál';
$lang['AppController.client_structure.default_title'] = 'Můj účet';
$lang['AppController.client_structure.staff_as_client_note'] = 'Zpět na portál pro zaměstnance';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'V současné době je povolen režim údržby a klienti se nemohou přihlásit. Pro změnu klikněte zde.';
$lang['AppController.structure.text_logout'] = 'Odhlášení';
$lang['AppController.structure.text_settings'] = 'Nastavení';
$lang['AppController.structure.text_myinfo'] = 'Moje informace';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Přepnutí zpět na můj účet';
$lang['AppController.banners.client_manager'] = 'V současné době spravujete účet, který vás ke správě vyzval.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Potvrďte prosím';
$lang['AppController.modal.text_close'] = 'Zavřít';
$lang['AppController.select.please'] = '-- Vyberte prosím --';
$lang['AppController.!success.license_key_updated'] = 'Váš licenční klíč byl úspěšně aktualizován. Přihlaste se prosím.';
$lang['AppController.!success.license_updated'] = 'Vaše licence byla úspěšně prodloužena. Přihlaste se prosím.';
$lang['AppController.!error.invalid_csrf'] = 'Token formuláře je neplatný.';
$lang['AppController.!error.unauthorized_access'] = 'Nejste oprávněni k přístupu k tomuto zdroji';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';

==> blesta-5.11.4.zip: blesta/language/cs_cz/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Přepínání navigace';
$lang['AppController.sreader.dropdown'] = 'Přepínání rozbalovacího seznamu';
$lang['AppController.graphs.label.total'] = 'Celkem';
$lang['AppController.graphs.control_label.grouped'] = 'Seskupení';
$lang['AppController.graphs.control_label.expanded'] = 'Rozšířená stránka';
$lang['AppController.graphs.control_label.stream'] = 'Stream';
$lang['AppController.graphs.control_label.stacked'] = 'Stacked';
$lang['AppController.dates.monthabbr_dec'] = 'Prosinec';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_oct'] = 'Říjen';
$lang['AppController.dates.monthabbr_sep'] = 'Září';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Květen';
$lang['AppController.dates.monthabbr_apr'] = 'Duben';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_feb'] = 'Únor';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Prosinec';
$lang['AppController.dates.month_nov'] = 'Listopad';
$lang['AppController.dates.month_oct'] = 'Říjen';
$lang['AppController.dates.month_sep'] = 'září';
$lang['AppController.dates.month_aug'] = 'Srpen';
$lang['AppController.dates.month_jul'] = 'Červenec';
$lang['AppController.dates.month_jun'] = 'červen';
$lang['AppController.dates.month_may'] = 'Květen';
$lang['AppController.dates.month_apr'] = 'duben';
$lang['AppController.dates.month_mar'] = 'Březen';
$lang['AppController.dates.month_feb'] = 'Únor';
$lang['AppController.dates.month_jan'] = 'Leden';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Pá';
$lang['AppController.dates.dayabbr_thur'] = 'Čt';
$lang['AppController.dates.dayabbr_wed'] = 'St';
$lang['AppController.dates.dayabbr_tue'] = 'Út';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_sun'] = 'Sun';
$lang['AppController.dates.day_sat'] = 'Sobota';
$lang['AppController.dates.day_fri'] = 'Pátek';
$lang['AppController.dates.day_thu'] = 'Čtvrtek';
$lang['AppController.dates.day_wed'] = 'Středa';
$lang['AppController.dates.day_tue'] = 'Úterý';
$lang['AppController.dates.day_mon'] = 'Pondělí';
$lang['AppController.dates.day_sun'] = 'Neděle';
$lang['AppController.client_structure.text_managers'] = 'Manažeři';
$lang['AppController.client_structure.text_contacts'] = 'Kontakty';
$lang['AppController.client_structure.text_accounts'] = 'Platební účty';
$lang['AppController.client_structure.text_emails'] = 'Historie e-mailů';
$lang['AppController.client_structure.text_update_account'] = 'Správa účtu';
$lang['AppController.client_structure.text_login'] = 'Přihlášení';
$lang['AppController.client_structure.text_logout'] = 'Odhlášení';
$lang['AppController.client_structure.text_return_to_portal'] = 'Návrat na portál';
$lang['AppController.client_structure.default_title'] = 'Můj účet';
$lang['AppController.client_structure.staff_as_client_note'] = 'Zpět na portál pro zaměstnance';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'V současné době je povolen režim údržby a klienti se nemohou přihlásit. Pro změnu klikněte zde.';
$lang['AppController.structure.text_logout'] = 'Odhlášení';
$lang['AppController.structure.text_settings'] = 'Nastavení';
$lang['AppController.structure.text_myinfo'] = 'Moje informace';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Přepnutí zpět na můj účet';
$lang['AppController.banners.client_manager'] = 'V současné době spravujete účet, který vás ke správě vyzval.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Potvrďte prosím';
$lang['AppController.modal.text_close'] = 'Zavřít';
$lang['AppController.select.please'] = '-- Vyberte prosím --';
$lang['AppController.!success.license_key_updated'] = 'Váš licenční klíč byl úspěšně aktualizován. Přihlaste se prosím.';
$lang['AppController.!success.license_updated'] = 'Vaše licence byla úspěšně prodloužena. Přihlaste se prosím.';
$lang['AppController.!error.invalid_csrf'] = 'Token formuláře je neplatný.';
$lang['AppController.!error.unauthorized_access'] = 'Nejste oprávněni k přístupu k tomuto zdroji';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Zde můžete nahrát soubory nebo kliknutím na tlačítko vybrat soubory';
$lang['AppController.!error.client_unauthorized_access'] = 'Nemáte oprávnění k přístupu k tomuto zdroji, obraťte se prosím na držitele primárního účtu a požádejte o přístup.';
